@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.104 2008/07/08 17:56:21 bisitz Exp $
+# $Id: lonlogin.pm,v 1.106.2.2 2008/12/25 05:53:17 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -201,7 +201,7 @@ sub handler {
                 $hostname.
                 '/adm/login?domain='.$authdomain.'">'.
                 $hostname.'</a>'.
-                ' (preferred)</font>'.$/;
+                ' '.&mt('(preferred)').'</font>'.$/;
 	    $last=$hostname;
         }
         $spares.= '<br />';
@@ -266,6 +266,14 @@ sub handler {
     if ($login eq '') {
         $login = $iconpath.'/'.&mt('userauthentication.gif');
     }
+    my $showbanner = 1;
+    my $showmainlogo = 1;
+    if (defined(&Apache::loncommon::designparm('login.showlogo_img',$domain))) {
+        $showbanner = &Apache::loncommon::designparm('login.showlogo_img',$domain);
+    }
+    if (defined(&Apache::loncommon::designparm('login.showlogo_logo',$domain))) {
+        $showmainlogo = &Apache::loncommon::designparm('login.showlogo_logo',$domain);
+    }
     my $showadminmail=&Apache::loncommon::designparm('login.adminmail',$domain);
     my $showcoursecat =
         &Apache::loncommon::designparm('login.coursecatalog',$domain);
@@ -346,8 +354,7 @@ my %lt=&Apache::lonlocal::texthash(
 		  'un'  => 'Username',
 		  'pw'  => 'Password',
 		  'dom' => 'Domain',
-		  'perc' => 'percent',
-		  'load' => 'Load',
+		  'load' => 'Server Load',
                   'userload' => 'User Load',
                   'about'  => 'About LON-CAPA',
                   'access' => 'Accessibility Options',
@@ -410,12 +417,21 @@ ENDSERVERFORM
     if ($shownewuserlink) {
         $newuserlink = &newuser_link($lt{'newuser'});
     }
-    if ($fullgraph) { $r->print(<<ENDTOP);
+    if ($fullgraph) {
+        $r->print(<<HEADER);
   <!-- The LON-CAPA Header -->
   <tr>
 
    <!-- Row 1 Columns 2-4 -->
-   <td width="100%" height=75 colspan=4 align="left" valign="top" bgcolor="$pgbg"><img src="$img" border=0 alt="The Learning Online Network with CAPA" /></td>
+   <td width="100%" height=75 colspan=4 align="left" valign="top" bgcolor="$pgbg">
+HEADER
+        if ($showbanner) {
+            $r->print(<<ENDBANNER); 
+<img src="$img" border=0 alt="The Learning Online Network with CAPA" />
+ENDBANNER
+        }
+        $r->print(<<ENDSTART);
+   </td>
   </tr>
 
   <!-- The gray bar that starts the two table frames -->
@@ -459,9 +475,15 @@ ENDSERVERFORM
    <!-- The right main column holding the large LON-CAPA logo-->
    <!-- Rows 3-4 Column 3 -->
    <td align="center" valign="top" width="100%" height="100%" bgcolor="$mainbg">
+ENDSTART
+        if ($showmainlogo) {
+            $r->print(<<ENDLOGO);
     <center>
      <img src="$logo" alt="" />
     </center>
+ENDLOGO
+        }
+        $r->print(<<ENDTOP);
    </td>
 
    <!-- Row 3 Column 4 -->
@@ -473,11 +495,11 @@ ENDSERVERFORM
    <!-- Row 4 Column 1 -->
    <td align="center" valign="middle" bgcolor="$sidebg">
 ENDTOP
-} else {
-    $r->print('<h1>The Learning<i>Online</i> Network with CAPA</h1>'
-             .'<h2>'.&mt('Text-based Interface Login').'</h2>'
-             .$announcements);
-}
+    } else {
+        $r->print('<h1>The Learning<i>Online</i> Network with CAPA</h1>'
+                 .'<h2>'.&mt('Text-based Interface Login').'</h2>'
+                 .$announcements);
+    }
     $r->print('<form name="client" onsubmit="return(send())">');
     unless ($fullgraph) {
         $r->print(<<ENDACCESSOPTIONS);
@@ -490,8 +512,8 @@ ENDTOP
 <br />
 <input type="checkbox" name="remember" /> $lt{'remember'}<hr />
 ENDACCESSOPTIONS
-} else {
-    $r->print(<<ENDNOOPT);
+    } else {
+        $r->print(<<ENDNOOPT);
 <input type="hidden" name="imagesuppress"  value="" />
 <input type="hidden" name="embedsuppress"  value="" />
 <input type="hidden" name="appletsuppress"  value="" />
@@ -499,7 +521,7 @@ ENDACCESSOPTIONS
 <input type="hidden" name="blackwhite"  value="" />
 <input type="hidden" name="remember"  value="" />
 ENDNOOPT
-}
+    }
     my $logintitle;
     if ($loginheader eq 'text') {
         $logintitle = '<td bgcolor="'.$bgcol.'" colspan="2">&nbsp;&nbsp;&nbsp;<b><font size="+1" color="'.$textcol.'">'.$lt{'log'}.'</font></b></td>';
@@ -576,7 +598,7 @@ ENDLOGIN
        <td bgcolor="$sidebg" align="left" valign="top">
         <small><b>&nbsp;&nbsp;&nbsp;$lt{'dom'}:&nbsp;</b></small>
        </td>
-       <td bgcolor="$sidebg" align="left" valign="top">
+       <td bgcolor="$sidebg" align="left" valign="middle">
         <small><tt>&nbsp;$domain</tt></small>
        </td>
       </tr>
@@ -584,24 +606,24 @@ ENDLOGIN
        <td bgcolor="$sidebg" align="left" valign="top">
         <small><b>&nbsp;&nbsp;&nbsp;$lt{'serv'}:&nbsp;</b></small>
        </td>
-       <td bgcolor="$sidebg" align="left" valign="top">
+       <td bgcolor="$sidebg" align="left" valign="middle">
         <small><tt>&nbsp;$lonhost ($role)</tt></small>
        </td>
       </tr>
       <tr>
-       <td bgcolor="$sidebg" align="left" valign="top">
-        <small><b>&nbsp;&nbsp;&nbsp;$lt{'load'}:&nbsp;</b></small>
+       <td bgcolor="$sidebg" align="left" valign="top"><span class="LC_nobreak">
+        <small><b>&nbsp;&nbsp;&nbsp;$lt{'load'}:&nbsp;</b></small></span>
        </td>
-       <td bgcolor="$sidebg" align="left" valign="top">
-        <small><tt>&nbsp;$loadpercent $lt{'perc'}</tt></small>
+       <td bgcolor="$sidebg" align="left" valign="middle">
+        <small><tt>&nbsp;$loadpercent%</tt></small>
        </td>
       </tr>
       <tr>
-       <td bgcolor="$sidebg" align="left" valign="top">
-        <small><b>&nbsp;&nbsp;&nbsp;$lt{'userload'}:&nbsp;</b></small>
+       <td bgcolor="$sidebg" align="left" valign="top"><span class="LC_nobreak">
+        <small><b>&nbsp;&nbsp;&nbsp;$lt{'userload'}:&nbsp;</b></small></span>
        </td>
-       <td bgcolor="$sidebg" align="left" valign="top">
-        <small><tt>&nbsp;$userloadpercent $lt{'perc'}</tt></small>
+       <td bgcolor="$sidebg" align="left" valign="middle">
+        <small><tt>&nbsp;$userloadpercent%</tt></small>
        </td>
       </tr>
      </table>
