@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.206 2008/09/03 04:28:22 raeburn Exp $
+# $Id: lonroles.pm,v 1.209 2008/10/20 03:25:48 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -483,6 +483,8 @@ ENDHEADER
     my $advanced=$env{'user.adv'};
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['tryagain']);
     my $tryagain=$env{'form.tryagain'};
+    my $reinit=$env{'user.reinit'};
+    delete $env{'user.reinit'};
 
 # -------------------------------------------------------- Generate Page Output
 # --------------------------------------------------------------- Error Header?
@@ -512,10 +514,16 @@ ENDHEADER
 					&Apache::lonenc::check_encrypt($fn));
     } else {
         if ($env{'user.error.msg'}) {
-	    $r->print(
+            if ($reinit) {
+                $r->print(
+ '<h3><span class="LC_error">'.
+ &mt('As your session file for the course has expired, you will need to re-select the course.').'</span></h3>');
+            } else {
+	        $r->print(
  '<h3><span class="LC_error">'.
  &mt('You need to choose another user role or enter a specific course for this function').'</span></h3>');
-	}
+	    }
+        }
     }
 # -------------------------------------------------------- Choice or no choice?
     if ($nochoose) {
@@ -689,7 +697,7 @@ ENDHEADER
                     $twhere=&mt('system wide');
 		    $sortkey=$role.$twhere;
                 }
-                $roletext.=&build_roletext($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$tfont,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver);
+                $roletext.=&build_roletext($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$tfont,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver,$reinit);
 		$roletext{$envkey}=$roletext;
 		if (!$sortkey) {$sortkey=$twhere."\0".$envkey;}
 		$sortrole{$sortkey}=$envkey;
@@ -742,30 +750,7 @@ ENDHEADER
         }
         $r->print(&Apache::loncommon::end_page());
 	return OK;
-# Is there only one choice?
-    } elsif ($countactive==1) {
-        my $needs_switchserver;
-        if ($env{'user.author'}) {
-            $needs_switchserver = &check_needs_switchserver($possiblerole);
-        }
-        if ((!$needs_switchserver) && ($env{'request.role'} eq 'cm')) {
-	    $r->print('<h3>'.&mt('Please stand by.').'</h3>'.
-	        '<input type="hidden" name="'.$possiblerole.'" value="1" />'.
-            '<noscript><br /><input type="submit" name="submit" value="'.&mt('Continue').'" /></noscript>');
-	    $r->print("</form>\n");
-	    $r->rflush();
-	    $r->print('<script type="text/javascript">document.forms.rolechoice.submit();</script>');
-	    $r->print(&Apache::loncommon::end_page());
-	    return OK;
-        }
-        if ($needs_switchserver) {
-            $r->print("<h2>".&mt('Server Switch Required')."</h2>\n".
-                      &mt('Construction Space access is only available from '.
-                          'the home server of the corresponding Author.').'<br />'.
-                      &mt("Click the 'Switch Server' link to go there.").'<br />');   
-        }
     }
-# More than one possible role
 # ----------------------------------------------------------------------- Table
     unless ((!&Apache::lonmenu::show_course()) || ($nochoose) || ($countactive==1)) {
 	$r->print("<h2>".&mt('Select a Course to Enter')."</h2>\n");
@@ -1011,7 +996,7 @@ sub role_status {
 }
 
 sub build_roletext {
-    my ($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$tfont,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver) = @_;
+    my ($trolecode,$tdom,$trest,$tstatus,$tryagain,$advanced,$tremark,$tbg,$tfont,$trole,$twhere,$tpstart,$tpend,$nochoose,$button,$switchserver,$reinit) = @_;
     my $roletext='<tr bgcolor="'.$tbg.'" class="LC_rolesmenu_'.$tstatus.'">';
     my $is_dc=($trolecode =~ m/^dc\./);
     my $rowspan=($is_dc) ? ''
@@ -1041,8 +1026,16 @@ sub build_roletext {
                 '<td'.$rowspan.'><input name="'.$buttonname.'" type="button" value="'.
                 &mt('Re-Initialize').'" onClick="javascript:enterrole(this.form,\''.
                         $trolecode."','".$buttonname.'\');" /></td>';
+        } elsif ($reinit) {
+            $roletext.= 
+                '<td'.$rowspan.'><input name="'.$buttonname.'" type="button" value="'.
+                &mt('Re-Select').'" onClick="javascript:enterrole(this.form,\''.
+                        $trolecode."','".$buttonname.'\');" /></td>';
         } else {
-            $roletext.='<td'.$rowspan.'>&nbsp;</td>';
+            $roletext.=
+                '<td'.$rowspan.'><input name="'.$buttonname.'" type="button" value="'.
+                &mt('Re-Initialize').'" onClick="javascript:enterrole(this.form,\''.
+                        $trolecode."','".$buttonname.'\');" /></td>';
         }
     }
     if ($trolecode !~ m/^(dc|ca|au|aa)\./) {
@@ -1159,7 +1152,15 @@ sub adhoc_course_role {
                         return;
                     }
                 }
-                my (%userroles,%newrole,%newgroups);
+                my (%userroles,%newrole,%newgroups,%group_privs);
+                my %cgroups =
+                    &Apache::lonnet::get_active_groups($env{'user.domain'},
+                                            $env{'user.name'},$cdom,$cnum);
+                foreach my $group (keys(%cgroups)) {
+                    $group_privs{$group} =
+                        $env{'user.priv.cc./'.$cdom.'/'.$cnum.'./'.$cdom.'/'.$cnum.'/'.$group};
+                }
+                $newgroups{'/'.$cdom.'/'.$cnum} = \%group_privs;
                 my $area = '/'.$cdom.'/'.$cnum;
                 my $spec = $role.'.'.$area;
                 if ($usec ne '') {
@@ -1167,7 +1168,7 @@ sub adhoc_course_role {
                     $area .= '/'.$usec;
                 }
                 &Apache::lonnet::standard_roleprivs(\%newrole,$role,$cdom,$spec,$cnum,$area);
-                &Apache::lonnet::set_userprivs(\%userroles,\%newrole,%newgroups);
+                &Apache::lonnet::set_userprivs(\%userroles,\%newrole,\%newgroups);
                 my $adhocstart = $then-1;
                 $userroles{'user.role.'.$spec} = $adhocstart.'.';
                 &Apache::lonnet::appenv(\%userroles,[$role,'cm']);
