@@ -2,7 +2,7 @@
 #
 # The LearningOnline Network
 #
-# $Id: modify_config_files.pl,v 1.7 2007/04/24 13:09:40 raeburn Exp $
+# $Id: modify_config_files.pl,v 1.8 2008/01/12 21:15:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -92,7 +92,7 @@ if ($dist =~ /^fedora\d+$/) {
                    value   => 'RHEL $releasever LON-CAPA $basearch Updates',
                }, {section => 'loncapa-updates-$basearch',
                    key     => 'baseurl=',
-                   value   => 'http://install.loncapa.org/redhat/linux/loncapa/'.
+                   value   => 'http://install.loncapa.org/redhat/linux/enterprise/loncapa/'.
                        '$releasever/$basearch',
                }, {section => 'loncapa-updates-$basearch',
                    key     => 'gpgcheck=',
@@ -106,7 +106,7 @@ if ($dist =~ /^fedora\d+$/) {
                    value   => 'RHEL $releasever LON-CAPA noarch Updates',
                }, {section => 'loncapa-updates-noarch',
                    key     => 'baseurl=',
-                   value   => 'http://install.loncapa.org/redhat/linux/loncapa/'.
+                   value   => 'http://install.loncapa.org/redhat/linux/enterprise/loncapa/'.
                        '$releasever/noarch',
                }, {section => 'loncapa-updates-noarch',
                    key     => 'gpgcheck=',
