@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.205 2008/09/23 19:15:57 raeburn Exp $
+# $Id: response.pm,v 1.206.2.1 2008/12/11 04:11:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -288,6 +288,7 @@ sub check_for_previous {
 		    $previous{'last'}='1';
 		}
 		if (! $previous{'award'} ) { $previous{'award'} = 'UNKNOWN';	}
+                if ($previous{'award'} eq 'INTERNAL_ERROR') { $previous{'used'}=0; }
 		&Apache::lonxml::debug("got a match :$previous{'award'}:$previous{'used'}:");
 	    }
 	}
@@ -680,7 +681,7 @@ sub start_responseparam {
 	    }
 	}
 	if (defined($optionlist)) {
-	    $result.='Use template: <select name="'.
+	    $result.=&mt('Use template:').' <select name="'.
 		&Apache::edit::html_element_name('parameter_package').'">'.
 		    '<option value=""></option>'.$optionlist.'</select><br />';
 	}
