@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # This will take annotations and then plug them into a page.
 #
-# $Id: admannotations.pm,v 1.27 2007/04/24 23:26:26 albertel Exp $
+# $Id: admannotations.pm,v 1.28.2.1 2008/12/11 13:36:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -40,8 +40,7 @@ use Apache::lonlocal;
 sub write_annotation {
     my ($symb, $enc, $annotation) = @_;
 
-    return if (!$annotation);
-
+    $annotation=~s/^\s*$//;
     my $key = $symb;
     if (!$enc) {
 	$key = 
@@ -52,19 +51,6 @@ sub write_annotation {
     return;
 }
 
-# --------------------------------------------------------------Get annotation
-
-sub get_annotation {
-    my ($symb,$enc) = @_;
-
-    my $key = $symb;
-    if (!$enc) {
-	$key = 
-	    &Apache::lonnet::clutter((&Apache::lonnet::decode_symb($symb))[2]);
-    }
-    my %annotation=&Apache::lonnet::get('nohist_annotations',[$key]);
-    return $annotation{$key};
-}
 
 # ------------------------------------------------------------Construct editor
 sub js_get_symb {
@@ -179,15 +165,6 @@ $end_page
 END_HTML2
 }
 
-sub clean_symb {
-    my ($symb) = @_;
-
-    &Apache::lonenc::check_decrypt(\$symb);
-    my $enc = $env{'request.enc'};
-    delete($env{'request.enc'});
-    
-    return ($symb,$enc);
-}
 
 # ---------------------------------------------------------------Main Handler
 
@@ -201,8 +178,8 @@ sub handler {
 
     my $page;
 
-    my ($symb_old,$symb_old_enc) = &clean_symb($env{'form.symbold'});
-    my ($symb_new,$symb_new_enc) = &clean_symb($env{'form.symbnew'});
+    my ($symb_old,$symb_old_enc) = &Apache::loncommon::clean_symb($env{'form.symbold'});
+    my ($symb_new,$symb_new_enc) = &Apache::loncommon::clean_symb($env{'form.symbnew'});
 
     my $annotation=$env{'form.annotation'};
 
@@ -214,7 +191,7 @@ sub handler {
 	    $page=&construct_error(&mt("Cannot annotate current window. Please point your browser to a LON-CAPA page and then 'continue'."),"continue");
 	} else {
 	    if ($symb_old ne $symb_new) {
-		$annotation=&get_annotation($symb_new,$symb_new_enc);
+		$annotation=&Apache::loncommon::get_annotation($symb_new,$symb_new_enc);
 	    }
 	    # pass same symb through.
 	    $page=&construct_editor($annotation,$env{'form.symbnew'});
