@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.41 2008/07/17 12:00:28 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.44 2008/09/23 20:31:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -398,6 +398,7 @@ sub cat_header {
 
 sub category_breadcrumbs {
     my ($dom,@cats) = @_;
+    my $crumbsymbol = ' &#x25b6; ';
     my ($currdepth,$deeper) = &get_depth_values();
     my $currcat_str = '<input type="hidden" name="catalog_maxdepth" value="'.$deeper.'" /><input type="hidden" name="showdom" value="'.$dom.'" />';
     my $catlinks = '<td valign="top"><b>'.&mt('Catalog:').'</b></td><td><table><tr>';
@@ -412,7 +413,7 @@ sub category_breadcrumbs {
             my ($cat,$container,$depth) = map { &unescape($_); } split(/:/,$env{'form.currcat_'.$shallower});
             $cattitle = $cat;
         }
-        $catlinks .= '<td valign="top"><a href="javascript:setCatDepth('."'$shallower'".')">'.$cattitle.'</a>-&gt;</td>';
+        $catlinks .= '<td valign="top"><a href="javascript:setCatDepth('."'$shallower'".')">'.$cattitle.'</a>'.$crumbsymbol.'</td>';
     }
     if ($deeper == 0) {
         $catlinks .= '<td>'.&mt('Main Categories').':&nbsp;';
@@ -810,7 +811,7 @@ sub construct_data_table {
             $output .=
               '<th>'.&mt('Default Access Dates for Students').'</th>'.
               '<th>'.&mt('Student Counts').'</th>'.
-              '<th>'.&mt('Auto-enrollment of <br />registered students').'</th>';
+              '<th>'.&mt('Auto-enrollment of[_1]registered students','<br />').'</th>';
         } else {
             $output .= '<th>'.&mt('Details').'</th>';
         }
@@ -957,10 +958,10 @@ sub build_courseinfo_hash {
                 }
             }
             if ($startaccess) {
-                $accessdates .= &mt('<i>From:</i> ').$startaccess.'<br />';
+                $accessdates .= '<i>'.&mt('From:[_1]','</i> '.$startaccess).'<br />';
             }
             if ($endaccess) {
-                $accessdates .= &mt('<i>To:</i> ').$endaccess.'<br />';
+                $accessdates .= '<i>'.&mt('To:[_1]','</i> '.$endaccess).'<br />';
             }
             if (($selfenroll_types ne '') && 
                 ($selfenroll_end > 0 && $selfenroll_end > $now)) {
@@ -981,10 +982,10 @@ sub build_courseinfo_hash {
                     if ($selfenroll_start_access || $selfenroll_end_access) {
                         $accessdates .= '<br/><br /><i>'.&mt('Self-enrollers:').'</i><br />';
                         if ($selfenroll_start_access) {
-                            $accessdates .= &mt('<i>From:</i> ').$selfenroll_start_access.'<br />';
+                            $accessdates .= '<i>'.&mt('From:[_1]','</i> '.$selfenroll_start_access).'<br />';
                         }
                         if ($selfenroll_end_access) {
-                            $accessdates .= &mt('<i>To:</i> ').$selfenroll_end_access.'<br />';
+                            $accessdates .= '<i>'.&mt('To:[_1]','</i> '.$selfenroll_end_access).'<br />';
                         }
                     }
                 }
@@ -1019,10 +1020,10 @@ sub count_students {
         $student_count{$data->[$idx{'status'}]} ++;
     }
 
-    my $countslist = &mt('[quant,_1,section]',$numsec).':<br />';
+    my $countslist = &mt('[quant,_1,section:,sections:,No sections]',$numsec).'<br />';
     foreach my $status ('Active','Future') {
-        $countslist .= '<nobr>'.$status_title{$status}.': '.
-                       $student_count{$status}.'</nobr><br />';
+        $countslist .= '<span class="LC_nobreak">'.$status_title{$status}.': '.
+                       $student_count{$status}.'</span><br />';
     }
     return $countslist;
 }
@@ -1162,11 +1163,11 @@ sub get_valid_classes {
     }
     if ($totalitems > 0) {
         if (@{$validations{'sections'}}) {
-            $response = &mt('Sections: ').
+            $response = &mt('Sections:').' '.
                         join(', ',@{$validations{'sections'}}).'<br />';
         }
         if (@{$validations{'xlists'}}) {
-            $response .= &mt('Courses: ').
+            $response .= &mt('Courses:').' '.
                         join(', ',@{$validations{'xlists'}});
         }
     }
@@ -1331,17 +1332,20 @@ sub autoenroll_info {
                    &get_valid_classes($seclist,$xlist_items,$code,
                                       $owners,$cdom,$cnum);
                 if ($valid_classes ne '') {
-                    $autoenrolldates = &mt('Not enabled<br />Starts: ').
-                                       $autostart.'<br />'.$valid_classes;                }
+                    $autoenrolldates = &mt('Not enabled').'<br />'
+                                      .&mt('Starts: [_1]',$autostart)
+                                      .'<br />'.$valid_classes;
+                }
             }
         } else {
             if ($coursehash->{'internal.autoend'} && $coursehash->{'internal.autoend'} < $now) {
-                $autoenrolldates = &mt('Not enabled<br />Ended: ').$autoend;
+                $autoenrolldates = &mt('Not enabled').'<br />'
+                                  .&mt('Ended: [_1]',$autoend);
             } else {
                 my $valid_classes = &get_valid_classes($seclist,$xlist_items,
                                                        $code,$owners,$cdom,$cnum);
                 if ($valid_classes ne '') {
-                    $autoenrolldates = &mt('Currently enabled<br />').
+                    $autoenrolldates = &mt('Currently enabled').'<br />'.
                                        $valid_classes;
                 }
             }
