@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # routines for clone a course
 #
-# $Id: lonclonecourse.pm,v 1.6 2008/01/22 22:37:18 www Exp $
+# $Id: lonclonecourse.pm,v 1.7 2008/09/11 13:19:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -47,9 +47,9 @@ sub innercrsdirlist {
     unless ($which) { $which=''; } else { $which.='/'; }
     unless ($path)  { $path=''; } else { $path.='/'; }
     my %crsdata=&Apache::lonnet::coursedescription($courseid);
+    my $getpropath = 1;
     my @listing=&Apache::lonnet::dirlist
-	($which,$crsdata{'domain'},$crsdata{'num'},
-	 &propath($crsdata{'domain'},$crsdata{'num'}));
+	($which,$crsdata{'domain'},$crsdata{'num'},$getpropath);
     foreach (@listing) {
 	unless ($_=~/^\./) {
 	    my @unpackline = split (/\&/,$_);
