@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.180 2008/09/05 22:12:47 riegler Exp $
+# $Id: lonhtmlcommon.pm,v 1.182 2008/10/07 10:13:58 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -102,18 +102,20 @@ can be used to paste LaTeX into a textarea.
 =cut
 
 sub dragmath_js {
+    my ($popup) = @_;
     return <<ENDDRAGMATHJS;
                 <script type="text/javascript">
                   function mathedit(textarea, doc) {
                      targetEntry = textarea;
                      targetDoc   = doc;
-                     newwin  = window.open("/adm/dragmath/applet/EditMathPopup.html","","width=565,height=500,resizable");
+                     newwin  = window.open("/adm/dragmath/applet/$popup.html","","width=565,height=500,resizable");
                   }
                 </script>
 
 ENDDRAGMATHJS
 }
 
+
 ##############################################
 ##############################################
 
@@ -1483,6 +1485,13 @@ END
     return $output;
 }
 
+sub row_headline {
+    my $output = <<"END";
+           <tr><td colspan="2">
+END
+    return $output;
+}
+
 sub row_title {
     my ($title,$css_title_class,$css_value_class) = @_;
     $css_title_class ||= 'LC_pick_box_title';
