@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.239.2.1 2008/09/20 17:01:48 raeburn Exp $
+# $Id: lonmenu.pm,v 1.239.4.2 2008/12/13 15:55:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1121,6 +1121,18 @@ sub rawconfig {
                     }
                 }
             }
+        } elsif ($pro eq 'tools') {
+            my @tools = ('aboutme','blog','portfolio');
+            if (grep(/^\Q$prt\E$/,@tools)) {
+                if (!&Apache::lonnet::usertools_access($env{'user.name'},
+                                                       $env{'user.domain'},$prt)) {
+                    $output.=&clear($row,$col);
+                    next;
+                }
+            }
+            $prt='any';
+            $output.=&secondlevel(
+          $uname,$udom,$rol,$crs,$pub,$con,$row,$col,$prt,$img,$top,$bot,$act,$desc,$cat);
         }
     }
     unless (($env{'browser.interface'} eq 'textual') ||
