@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Metadata display handler
 #
-# $Id: lonmeta.pm,v 1.212 2008/03/06 20:20:18 www Exp $
+# $Id: lonmeta.pm,v 1.212.2.4 2008/12/17 18:47:08 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -182,7 +182,7 @@ sub evalgraph {
     my $val=int($value*10.+0.5)-10;
     my $output='<table border="0" cellpadding="0" cellspacing="0"><tr>';
     if ($val>=20) {
-	$output.='<td width="20" bgcolor="#555555">&nbsp&nbsp;</td>';
+	$output.='<td width="20" bgcolor="#555555">'.('&nbsp;' x2).'</td>';
     } else {
         $output.='<td width="'.($val).'" bgcolor="#555555">&nbsp;</td>'.
                  '<td width="'.(20-$val).'" bgcolor="#FF3333">&nbsp;</td>';
@@ -192,7 +192,7 @@ sub evalgraph {
 	$output.='<td width="'.($val-20).'" bgcolor="#33FF33">&nbsp;</td>'.
                  '<td width="'.(40-$val).'" bgcolor="#555555">&nbsp;</td>';
     } else {
-        $output.='<td width="20" bgcolor="#555555">&nbsp&nbsp;</td>';
+        $output.='<td width="20" bgcolor="#555555">'.('&nbsp;' x2).'</td>';
     }
     $output.='<td> ('.sprintf("%5.2f",$value).') </td></tr></table>';
     return $output;
@@ -573,12 +573,13 @@ sub selectbox {
         $functionref=\&direct;
     }
     my $selout='<select name="'.$name.'">';
-    foreach (@idlist) {
-        $selout.='<option value=\''.$_.'\'';
-        if ($_ eq $value) {
+    foreach my $id (@idlist) {
+        $selout.='<option value="'.$id.'"';
+        if ($id eq $value) {
 	    $selout.=' selected>'.&{$functionref}($_).'</option>';
-	}
-        else {$selout.='>'.&{$functionref}($_).'</option>';}
+        } else {
+            $selout.='>'.&{$functionref}($id).'</option>';
+        }
     }
     return $selout.'</select>';
 }
@@ -850,11 +851,11 @@ sub report_bombs {
 ENDCLEAR
         my %brokenurls = 
             &Apache::lonmsg::all_url_author_res_msg($author,$domain);
-        foreach (sort(keys(%brokenurls))) {
-            if ($_=~/^\Q$uri\E/) {
+        foreach my $key (sort(keys(%brokenurls))) {
+            if ($key=~/^\Q$uri\E/) {
                 $r->print
-                    ('<a href="'.&Apache::lonnet::clutter($_).'">'.$_.'</a>'.
-                     &Apache::lonmsg::retrieve_author_res_msg($_).
+                    ('<a href="'.&Apache::lonnet::clutter($key).'">'.$key.'</a>'.
+                     &Apache::lonmsg::retrieve_author_res_msg($key).
                      '<hr />');
             }
         }
@@ -877,8 +878,8 @@ sub present_uneditable_metadata {
     my $uploaded = ($uri =~ m|/uploaded/|);
     my %content=();
     # Read file
-    foreach (split(/\,/,&Apache::lonnet::metadata($uri,'keys'))) {
-        $content{$_}=&Apache::lonnet::metadata($uri,$_);
+    foreach my $key (split(/\,/,&Apache::lonnet::metadata($uri,'keys'))) {
+        $content{$key}=&Apache::lonnet::metadata($uri,$key);
     }
     # Render Output
     # displayed url
@@ -906,9 +907,9 @@ sub present_uneditable_metadata {
     my $obsolete=$content{'obsolete'};
     my $obsoletewarning='';
     if (($obsolete) && ($env{'user.adv'})) {
-        $obsoletewarning='<p><font color="red">'.
+        $obsoletewarning='<p><span class="LC_warning">'.
             &mt('This resource has been marked obsolete by the author(s)').
-            '</font></p>';
+            '</span></p>';
     }
     #
     my %lt=&fieldnames();
@@ -944,24 +945,27 @@ sub present_uneditable_metadata {
 		   'obsolete', 
 		   'obsoletereplacement');
     }
+    my $rownum = 0;
     foreach my $field (@fields) {
-        $table.='<tr><td bgcolor="#AAAAAA">'.$lt{$field}.
-            '</td><td bgcolor="#CCCCCC">'.
-            &prettyprint($field,$content{$field}).'</td></tr>';
+        my $lastrow = '';
+        $rownum ++;
+        $lastrow = 1 if ($rownum == @fields);
+        $table.=&Apache::lonhtmlcommon::row_title($lt{$field})
+                .&prettyprint($field,$content{$field})
+                .&Apache::lonhtmlcommon::row_closure($lastrow);
         delete($content{$field});
     }
     #
-    $r->print(<<ENDHEAD);
-<h2>$title</h2>
-<p>
-$disuri<br />
-$obsoletewarning
-$versiondisplay
-</p>
-<table cellspacing="2" border="0">
-$table
-</table>
-ENDHEAD
+    $r->print("<h2>$title</h2>"
+              .'<p>'
+              .$disuri.'<br />'
+              .$obsoletewarning
+              .$versiondisplay
+              .'</p>'
+              .&Apache::lonhtmlcommon::start_pick_box()
+              .$table
+              .&Apache::lonhtmlcommon::end_pick_box()
+    );
     if (!$uploaded && $env{'user.adv'}) {
         &print_dynamic_metadata($r,$uri,\%content);
     }
@@ -988,17 +992,21 @@ sub print_dynamic_metadata {
         exists($dynmeta{'goto'}) ||
         exists($dynmeta{'course'})) {
         $r->print('<h4>'.&mt('Access and Usage Statistics').'</h4>'.
-                  '<table cellspacing="2" border="0">');
-        foreach ('count',
-                 'sequsage','sequsage_list',
-                 'comefrom','comefrom_list',
-                 'goto','goto_list',
-                 'course','course_list') {
-            $r->print('<tr><td bgcolor="#AAAAAA">'.$lt{$_}.'</td>'.
-                      '<td bgcolor="#CCCCCC">'.
-                      &prettyprint($_,$dynmeta{$_})."</td></tr>\n");
+                  &Apache::lonhtmlcommon::start_pick_box());
+        my @counts = ('count','sequsage','sequsage_list',
+                      'comefrom','comefrom_list','goto',
+                      'goto_list','course','course_list');
+        my $rownum = 0;
+        foreach my $item (@counts) {
+            my $lastrow = '';
+            $rownum ++;
+            $lastrow = 1 if ($rownum == @counts);
+            $r->print(&Apache::lonhtmlcommon::row_title($lt{$item})
+                      .&prettyprint($item,$dynmeta{$item})
+                      .&Apache::lonhtmlcommon::row_closure($lastrow)
+            );
         }
-        $r->print('</table>');
+        $r->print(&Apache::lonhtmlcommon::end_pick_box());
     } else {
         $r->print('<h4>'.&mt('No Access or Usages Statistics are available for this resource.').'</h4>');
     }
@@ -1013,18 +1021,23 @@ sub print_dynamic_metadata {
             $r->print('<h4>'.
                       &mt('Overall Assessment Statistical Data').
                       '</h4>'.
-                      '<table cellspacing="2" border="0">');
-            $r->print('<tr><td bgcolor="#AAAAAA">'.$lt{'stdno'}.'</td>'.
-                      '<td bgcolor="#CCCCCC">'.
-                      &prettyprint('stdno',$dynmeta{'stdno'}).
-                      '</td>'."</tr>\n");
-            foreach ('avetries','difficulty','disc') {
-                $r->print('<tr><td bgcolor="#AAAAAA">'.$lt{$_}.'</td>'.
-                          '<td bgcolor="#CCCCCC">'.
-                          &prettyprint($_,sprintf('%5.2f',$dynmeta{$_})).
-                          '</td>'."</tr>\n");
+                      &Apache::lonhtmlcommon::start_pick_box());
+            $r->print(&Apache::lonhtmlcommon::row_title($lt{'stdno'})
+                      .&prettyprint('stdno',$dynmeta{'stdno'})
+                      .&Apache::lonhtmlcommon::row_closure()
+            );
+            my @stats = ('avetries','difficulty','disc');
+            my $rownum = 0;
+            foreach my $item (@stats) {
+                my $lastrow = '';
+                $rownum ++;
+                $lastrow = 1 if ($rownum == @stats);
+                $r->print(&Apache::lonhtmlcommon::row_title($lt{$item})
+                          .&prettyprint($item,sprintf('%5.2f',$dynmeta{$item}))
+                          .&Apache::lonhtmlcommon::row_closure($lastrow)
+                );
             }
-            $r->print('</table>');    
+            $r->print(&Apache::lonhtmlcommon::end_pick_box());    
         }
         if (exists($dynmeta{'stats'})) {
             #
@@ -1032,16 +1045,16 @@ sub print_dynamic_metadata {
             $r->print('<h4>'.
                       &mt('Recent Detailed Assessment Statistical Data').
                       '</h4>');
-            my $table = '<table cellspacing="2" border="0">'.
-                '<tr>'.
-                '<th>'.&mt('Course').'</th>'.
-                '<th>'.&mt('Section(s)').'</th>'.
-                '<th>'.&mt('Num Student').'s</th>'.
-                '<th>'.&mt('Mean Tries').'</th>'.
-                '<th>'.&mt('Degree of Difficulty').'</th>'.
-                '<th>'.&mt('Degree of Discrimination').'</th>'.
-                '<th>'.&mt('Time of computation').'</th>'.
-                '</tr>'.$/;
+            my $table=&Apache::loncommon::start_data_table()
+                      .&Apache::loncommon::start_data_table_header_row()
+                      .'<th>'.&mt('Course').'</th>'
+                      .'<th>'.&mt('Section(s)').'</th>'
+                      .'<th>'.&mt('Num Student').'s</th>'
+                      .'<th>'.&mt('Mean Tries').'</th>'
+                      .'<th>'.&mt('Degree of Difficulty').'</th>'
+                      .'<th>'.&mt('Degree of Discrimination').'</th>'
+                      .'<th>'.&mt('Time of computation').'</th>'
+                      .&Apache::loncommon::end_data_table_header_row().$/;
             foreach my $identifier (sort(keys(%{$dynmeta{'stats'}}))) {
                 my $data = $dynmeta{'stats'}->{$identifier};
                 my $course = $data->{'course'};
@@ -1052,30 +1065,29 @@ sub print_dynamic_metadata {
                     &Apache::lonnet::logthis('lookup for '.$course.' failed');
                     next;
                 }
-                $table .= '<tr>';
+                $table .= &Apache::loncommon::start_data_table_row();
                 $table .= 
-                    '<td><nobr>'.$courseinfo{'description'}.'</nobr></td>';
+                    '<td><span class="LC_nobreak">'.$courseinfo{'description'}.'</span></td>';
                 $table .= 
                     '<td align="right">'.$data->{'sections'}.'</td>';
                 $table .=
                     '<td align="right">'.$data->{'stdno'}.'</td>';
-                foreach ('avetries','difficulty','disc') {
+                foreach my $item ('avetries','difficulty','disc') {
                     $table .= '<td align="right">';
-                    if (exists($data->{$_})) {
-                        $table .= sprintf('%.2f',$data->{$_}).'&nbsp;';
+                    if (exists($data->{$item})) {
+                        $table .= sprintf('%.2f',$data->{$item}).'&nbsp;';
                     } else {
                         $table .= '';
                     }
                     $table .= '</td>';
                 }
                 $table .=
-                    '<td><nobr>'.
+                    '<td><span class="LC_nobreak">'.
                     &Apache::lonlocal::locallocaltime($data->{'timestamp'}).
-                    '</nobr></td>';
-                $table .=
-                    '</tr>'.$/;
+                    '</span></td>';
+                $table .= &Apache::loncommon::end_data_table_row().$/;
             }
-            $table .= '</table>'.$/;
+            $table .= &Apache::loncommon::end_data_table().$/;
             $r->print($table);
         } else {
             $r->print(&mt('No new dynamic data found.'));
@@ -1094,13 +1106,19 @@ sub print_dynamic_metadata {
         exists($dynmeta{'correct'}) || 
         exists($dynmeta{'technical'})){ 
         $r->print('<h4>'.&mt('Evaluation Data').'</h4>'.
-                  '<table cellspacing="2" border="0">');
-        foreach ('clear','depth','helpful','correct','technical') {
-            $r->print('<tr><td bgcolor="#AAAAAA">'.$lt{$_}.'</td>'.
-                      '<td bgcolor="#CCCCCC">'.
-                      &prettyprint($_,$dynmeta{$_})."</td></tr>\n");
+                  &Apache::lonhtmlcommon::start_pick_box());
+        my @criteria = ('clear','depth','helpful','correct','technical');
+        my $rownum = 0;
+        foreach my $item (@criteria) {
+            my $lastrow = '';
+            $rownum ++;
+            $lastrow = 1 if ($rownum == @criteria);
+            $r->print(&Apache::lonhtmlcommon::row_title($lt{$item})
+                      .&prettyprint($item,$dynmeta{$item})
+                      .&Apache::lonhtmlcommon::row_closure($lastrow)
+            );
         }
-        $r->print('</table>');
+        $r->print(&Apache::lonhtmlcommon::end_pick_box());
     } else {
         $r->print('<h4>'.&mt('No Evaluation Data is available for this resource.').'</h4>');
     }
@@ -1128,32 +1146,44 @@ sub print_dynamic_metadata {
     # All other stuff
     $r->print('<h3>'.
               &mt('Additional Metadata (non-standard, parameters, exports)').
-              '</h3><table border="0" cellspacing="1">');
-    foreach (sort(keys(%content))) {
-        my $name=$_;
-        if ($name!~/\.display$/) {
+              '</h3>');
+    $r->print(&Apache::lonhtmlcommon::start_pick_box());
+    my @names;
+    foreach my $key (sort(keys(%content))) {
+        if ($key!~/\.display$/) {
+            push(@names,$key);
+        }
+    }
+    if (@names > 0) {
+        my $rownum = 0;
+        foreach my $name (@names) {
+            my $lastrow = '';
+            $rownum ++;
+            $lastrow = 1 if ($rownum == @names);
+
             my $display=&Apache::lonnet::metadata($uri,
                                                   $name.'.display');
             if (! $display) { 
                 $display=$name;
             };
             my $otherinfo='';
-            foreach ('name','part','type','default') {
+            foreach my $item ('name','part','type','default') {
                 if (defined(&Apache::lonnet::metadata($uri,
-                                                      $name.'.'.$_))) {
-                    $otherinfo.=' '.$_.'='.
+                                                      $name.'.'.$item))) {
+                    $otherinfo.=' '.$item.'='.
                         &Apache::lonnet::metadata($uri,
-                                                  $name.'.'.$_).'; ';
+                                                  $name.'.'.$item).'; ';
                 }
             }
-            $r->print('<tr><td bgcolor="#bbccbb"><font size="-1" color="#556655">'.$display.'</font></td><td bgcolor="#ccddcc"><font size="-1" color="#556655">'.$content{$name});
+            $r->print(&Apache::lonhtmlcommon::row_title($display)
+                      .$content{$name});
             if ($otherinfo) {
                 $r->print(' ('.$otherinfo.')');
             }
-            $r->print("</font></td></tr>\n");
+            $r->print(&Apache::lonhtmlcommon::row_closure($lastrow));
         }
     }
-    $r->print("</table>");
+    $r->print(&Apache::lonhtmlcommon::end_pick_box());
     return;
 }
 
