@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Simple Page Editor
 #
-# $Id: lonsimplepage.pm,v 1.56 2008/03/20 12:06:51 bisitz Exp $
+# $Id: lonsimplepage.pm,v 1.57 2008/10/20 16:29:59 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -415,7 +415,7 @@ sub display_group_links {
                 $output .= '<td>'.&mt($menu{$tool}{text}).'</td>';
             } else {
                 $output .= '<td><a href="'.$menu{$tool}{href}.'">'.
-                           $menu{$tool}{text}.'</a></td>';
+                           &mt($menu{$tool}{text}).'</a></td>';
             }
         }
         $output .= '</tr></table>';
@@ -429,7 +429,7 @@ sub display_group_links {
         if ($context eq 'edit') {
             $output = &mt('No group functionality.');
         } else {  
-            $output = &mt('No group functionality (e.g., e-mail, discussion, chat or file upload) is currently available to you in this group: <b>[_1]</b>.',&unescape($groupinfo{'description'}));
+            $output = &mt('No group functionality (e.g., e-mail, discussion, chat or file upload) is currently available to you in this group: [_1].','<b>'.&unescape($groupinfo{'description'}).'</b>');
         }
         if ($target eq 'tex') {
             $r->print(&Apache::lonxml::xmlparse($r,'tex',$output));
