@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstatistics.pm,v 1.141 2008/09/16 15:40:15 bisitz Exp $
+# $Id: lonstatistics.pm,v 1.142.2.1 2008/12/12 17:11:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -462,7 +462,7 @@ sub section_and_enrollment_description {
     $description = &section_or_group_text($mode,'section',@sections).
 	' '.&section_or_group_text($mode,'group',@groups);
     if ($mode eq 'localized') {
-        $description .= &mt(' [_1] access status.',$env{'form.Status'});
+        $description .= ' '.&mt($env{'form.Status'}.' access status.');
     } elsif ($mode eq 'plaintext') {
         $description .= ' '.$env{'form.Status'}.' access status.';
     }
@@ -488,21 +488,21 @@ sub section_or_group_text {
                              );
     if (scalar(@items) == 1 && $items[0] ne 'all') {
         if ($mode eq 'localized') {
-            $text = &mt('[_1] [_2].',$phrases{$type}{single},$items[0]);
+            $text = &mt($phrases{$type}{single}.' [_1].',$items[0]);
         } elsif ($mode eq 'plaintext') {
             $text = $phrases{$type}{single}.' '.$items[0].'.';
 
         }
     } elsif (scalar(@items) && $items[0] eq 'all') {
         if ($mode eq 'localized') {
-            $text = &mt('[_1].',$phrases{$type}{all});
+            $text = &mt($phrases{$type}{all}.'.');
         } elsif ($mode eq 'plaintext') {
             $text = $phrases{$type}{all}.'.';
         }
     } elsif (scalar(@items)) {
         my $lastitem = pop(@items);
         if ($mode eq 'localized') {
-            $text = &mt('[_1] [_2] and [_3].',$phrases{$type}{plural},
+            $text = &mt($phrases{$type}{plural}.' [_1] and [_2].',
                         join(', ',@items),$lastitem);
         } elsif ($mode eq 'plaintext') {
             $text = $phrases{$type}{plural}.' '.join(', ',@items).' and '.
@@ -1035,7 +1035,7 @@ sub DisplayClasslist {
                 $Str .= '&sort='.&escape($env{'form.sort'});
                 $Str .= '&SelectedStudent=';
                 $Str .= &escape($sname).'">';
-                $Str .= $student->{$field}.'&nbsp';
+                $Str .= $student->{$field}.'&nbsp;';
                 $Str .= '</a>';
             } elsif ($field eq 'status') {
                 $Str .= &mt($student->{$field});
