@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Syllabus
 #
-# $Id: lonsyllabus.pm,v 1.67 2008/08/25 14:50:01 raeburn Exp $
+# $Id: lonsyllabus.pm,v 1.69.2.1 2008/12/24 08:10:09 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -179,14 +179,15 @@ ENDSCRIPT
 # -------------------------------------------------------- Get course personnel
     my %coursepersonnel=&Apache::lonnet::get_course_adv_roles($cdom.'/'.$cnum);
     if ($target ne 'tex') {
-	$r->print(&Apache::loncommon::start_data_table());
+	$r->print(&Apache::lonhtmlcommon::start_pick_box());
     } else {
 	$r->print('\begin{tabular}{|p{0.45\textwidth}|p{0.45\textwidth}|}\hline');
     }
-    foreach my $element (sort keys %coursepersonnel) {
+    my @personnel=sort keys %coursepersonnel;
+    my $lastpers=$personnel[$#personnel];
+    foreach my $element (@personnel) {
 	if ($target ne 'tex') {
-	    $r->print(&Apache::loncommon::start_data_table_row().
-		      '<td>'.$element.'</td><td>');
+	    $r->print(&Apache::lonhtmlcommon::row_title($element));
 	} else {
 	    $r->print(' '.&Apache::lonxml::xmlparse($r,'tex',$element).' & '); 
 	}
@@ -207,13 +208,14 @@ ENDSCRIPT
 	    }
 	}
 	if ($target ne 'tex') {
-	    $r->print('</td>'.&Apache::loncommon::end_data_table_row());
+            my $lastclose=$element eq $lastpers?1:0;
+            $r->print(&Apache::lonhtmlcommon::row_closure($lastclose));
 	} else {
 	    $r->print('\\\\ \hline');
 	}
     }
     if ($target ne 'tex') {
-	$r->print(&Apache::loncommon::end_data_table());
+	$r->print(&Apache::lonhtmlcommon::end_pick_box());
     } else {
 	$r->print('\end{tabular}\\\\');
     }
@@ -237,9 +239,11 @@ ENDSCRIPT
           if ($forcestudent or $target eq 'tex') { $allowed=0; }
        }
        if ($allowed) {
+          my $protocol = $Apache::lonnet::protocol{$homeserver};
+          $protocol = 'http' if ($protocol ne 'https');
           $r->print('<p>'.
 &Apache::loncommon::help_open_topic('Uploaded_Templates_TextBoxes',&mt('Help with filling in text boxes')).'</p><p>'.&mt('This syllabus can be publicly viewed at')
-		    .' <tt>http://'.
+		    .' <tt>'.$protocol.'://'.
 		    &Apache::lonnet::hostname($homeserver).$r->uri.'</tt>'.
                &Apache::loncommon::help_open_topic('Syllabus_ExtLink').'</p>'.
           '<p>'.&mt('You can specify an external URL as Syllabus in the [_1].','<a href="/adm/parmset?action=crsenv">'.&mt('Course Parameters').'</a>').'</p>'.
@@ -269,7 +273,7 @@ ENDSCRIPT
 # get rid of leading and trailing spaces
                       $url=~s/^\s+//;
                       $url=~s/\s+$//;
-                      if ($url=~m|^http://([^/]+)/(.+)$|) {
+                      if ($url=~m|^https?\://([^/]+)/(.+)$|) {
 			  my $host = $1;
                           my $remainder=$2;
 # remove the hostname from internal URLs
@@ -282,7 +286,7 @@ ENDSCRIPT
 		          }
 		      }
 # norm internal URLs
-                      unless ($url=~/^http\:/) {
+                      unless ($url=~/^https?\:/) {
 		          $url=&Apache::lonnet::clutter($url);
                       }
 # re-assemble field
@@ -359,7 +363,7 @@ ENDSCRIPT
 		   } 
 	       } else {
 		   &Apache::lonfeedback::newline_to_br(\$message);
-		   $message =~s|(https*://[^\s]+)|<a href="$1"><tt>$1</tt></a>|g;
+		   $message =~s|(https?\://[^\s]+)|<a href="$1"><tt>$1</tt></a>|g;
 		   if ($allowed) {
 		       $message=&Apache::lonspeller::markeduptext($message);
 		   }
