@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lontrackstudent.pm,v 1.23 2007/02/13 01:44:02 albertel Exp $
+# $Id: lontrackstudent.pm,v 1.25 2008/12/20 04:31:55 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -360,14 +360,14 @@ sub output_results {
         my $tablerow = qq{<tr class="$class"><td>}.($count+1).qq{</td>};
         if ($src =~ m|^/adm/|) {
             $tablerow .= 
-                '<td valign="top"><nobr>'.$title.'</nobr></td>';
+                '<td valign="top"><span class="LC_nobreak">'.$title.'</span></td>';
         } else {
             $tablerow .= 
-                '<td valign="top"><nobr>'.
+                '<td valign="top"><span class="LC_nobreak">'.
                 '<a href="'.$src.'">'.$title.'</a>'.
-                '</nobr></td>';
+                '</span></td>';
         }
-        $tablerow .= '<td valign="top"><nobr>'.$timestamp.'</nobr></td>';
+        $tablerow .= '<td valign="top"><span class="LC_nobreak">'.$timestamp.'</span></td>';
         if ($mode eq 'full_class') {
             $tablerow.='<td valign="top">'.$student.'</td>';
         }
@@ -516,6 +516,11 @@ sub handler {
     #
     # We will almost always need this...
     my $navmap = Apache::lonnavmaps::navmap->new();
+    if (!defined($navmap)) {
+        my $requrl = $r->uri;
+        $env{'user.error.msg'} = "$requrl:bre:0:0:Navmap initialization failed.";
+        return HTTP_NOT_ACCEPTABLE;
+    }
     # 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({href=>'/adm/studentactivity',
