@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonproblemanalysis.pm,v 1.130 2007/01/04 02:44:07 albertel Exp $
+# $Id: lonproblemanalysis.pm,v 1.134 2008/12/12 07:26:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -78,7 +78,10 @@ sub BuildProblemAnalysisPage {
     my @Students = @Apache::lonstatistics::Students;
     #
     if (@Students < 1 && exists($env{'form.firstrun'})) {
-        $r->print('<h2>There are no students in the sections/groups selected</h2>');
+        $r->print('<div class="LC_warning">'
+                 .&mt('There are no students in the sections/groups selected.')
+                 .'</div>'
+        );
     }
     #
     my @CacheButtonHTML = 
@@ -141,7 +144,10 @@ sub BuildProblemAnalysisPage {
             $r->print('<h3>'.$resource->src.'</h3>');
             $r->print('<h4>'.&Apache::lonstatistics::section_and_enrollment_description().'</h4>');
             if ($env{'form.show_prob'} eq 'true') {
-                $r->print(&Apache::lonstathelpers::render_resource($resource));
+                $r->print('<hr />'
+                         .&Apache::lonstathelpers::render_resource($resource)
+                         .'<hr />'
+                );
             }
             $r->rflush();
 	    if (@Students) {
@@ -162,7 +168,11 @@ sub BuildProblemAnalysisPage {
 		    &numerical_response_analysis($r,$current_problem,
 						 $problem_data,\@Students);
 		} else {
-		    $r->print('<h2>Analysis of '.$current_problem->{'resptype'}.' is not supported</h2>');
+		    $r->print('<div class="LC_warning">'
+                             .&mt('Analysis of [_1] is not supported.'
+                                 ,$current_problem->{'resptype'})
+                             .'</div>'
+                    );
 		}
 	    }
         }
@@ -214,9 +224,10 @@ sub numerical_response_analysis {
     }
     #
     if (ref($response_data) ne 'ARRAY') {
-        $r->print('<h2>'.
-                  &mt('There is no submission data for this resource').
-                  '</h2>');
+        $r->print('<div class="LC_warning">'
+                 .&mt('There is no submission data for this resource.')
+                 .'</div>'
+        );
         return;
     }
     my $analysis_html = '<table>';
@@ -233,7 +244,7 @@ sub numerical_response_analysis {
             $stats_message = 
                 '[_1] submissions, [_2] correct, [_3] incorrect';
             $post_message = '';
-            $no_data_message = 'No data exists for attempt [_1]';
+            $no_data_message = 'No data exists for attempt [_1].';
         } else {
             my $starttime = &Apache::lonhtmlcommon::get_date_from_form
                 ('startdate_'.$plot_num);
@@ -281,9 +292,9 @@ sub numerical_response_analysis {
                                           $restriction_function);
         if ($stats->{'submission_count'} == 0) {
             $analysis_html.= 
-                '<tr><td colspan="2"><font size="+1"><b>'.
+                '<tr><td colspan="2"><div class="LC_warning">'.
                 &mt($no_data_message,$plot_num,@extra_data).
-                '</b></font></td></tr>';
+                '</div></td></tr>';
         } else {
             $analysis_html.= 
                 '<tr><td colspan="2" align="center"><font size="+1"><b>'.
@@ -830,9 +841,9 @@ sub radio_response_analysis {
     }
     #
     if (! defined($response_data) || ref($response_data) ne 'ARRAY' ) {
-        $analysis_html = '<h2>'.
-            &mt('There is no submission data for this resource').
-            '</h2>';
+        $analysis_html = '<div class="LC_warning">'
+                        .&mt('There is no submission data for this resource.')
+                        .'</div>';
         $r->print($analysis_html);
         return;
     }
@@ -863,7 +874,9 @@ sub radio_response_analysis {
                  &get_time_from_row($response_data->[-1]),
                  $plot_num);
             $pre_graph_text = 
-                'Data from [_6] to [_7]<br /> [_2] submissions from [_5] students, [_3] correct, [_4] incorrect';
+                'Data from [_6] to [_7]'
+               .'<br />'
+               .'[_2] submissions from [_5] students, [_3] correct, [_4] incorrect';
             $extra_data[0] = &Apache::lonlocal::locallocaltime($starttime);
             $extra_data[1] = &Apache::lonlocal::locallocaltime($endtime);
             #
@@ -951,11 +964,13 @@ sub radio_response_analysis {
             }
         } elsif ($no_data_text ne '') {
             $analysis_html.='<tr><td colspan="4" align="center">'.
+                '<div class="LC_warning">'.
                 &mt($no_data_text,
                     $plot_num,$foil_choice_data->{'_count'},
                     $correct,                    
                     $foil_choice_data->{'_count'}-$correct,
-                    @extra_data);
+                    @extra_data).
+                '</div>';
             if (defined($post_graph_text)) {
                 $analysis_html.='<br />'.$post_graph_text;
             }
@@ -1217,9 +1232,10 @@ sub OptionResponseAnalysis {
          $resource->symb,$respid);
     if (! defined($PerformanceData) || 
         ref($PerformanceData) ne 'ARRAY' ) {
-        $r->print('<h2>'.
-                  &mt('There is no student data for this problem.').
-                  '</h2>');
+        $r->print('<div class="LC_warning">'
+                 .&mt('There is no student data for this problem.')
+                 .'</div>'
+        );
     }  else {
         $r->rflush();
         if ($env{'form.AnalyzeOver'} eq 'tries') {
@@ -1234,10 +1250,10 @@ sub OptionResponseAnalysis {
             $r->print($analysis_html);
             $r->rflush();
         } else {
-            $r->print('<h2>'.
-                      &mt('The analysis you have selected is '.
-                          'not supported at this time').
-                      '</h2>');
+            $r->print('div class="LC_warning"'
+                     .&mt('The analysis you have selected is not supported at this time.')
+                     .'</div>'
+            );
         }
     }
 }
@@ -1314,12 +1330,18 @@ sub OR_tries_analysis {
         if (! defined($response_data{'_total'}->[$try]) ||
             $response_data{'_total'}->[$try] == 0) { 
             if ($try > 1) {
-                $analysis_html.= '<tr><td align="center" colspan="4"><b>'.
-                    &mt('None of the selected students attempted the problem more than [_1] times.',$try-1).
-                    '</b></td></tr>';
+                $analysis_html.= '<tr><td colspan="4">'
+                                .'<div class="LC_info">'
+                                .&mt('None of the selected students attempted the problem more than [_1] times.'
+                                    ,$try-1)
+                                .'</div>'
+                                .'</td></tr>';
             } else {
-                $analysis_html.= '<tr><td colspan="4" align="center"><b>'.
-                    &mt('None of the selected students have attempted the problem').'</b></td></tr>';
+                $analysis_html.= '<tr><td colspan="4">'
+                                .'<div class="LC_info">'
+                                .&mt('None of the selected students have attempted the problem.')
+                                .'</div>'
+                                .'</td></tr>';
             }
             last;
         }
@@ -1547,7 +1569,11 @@ sub OR_Foil_Time_Analysis {
     my ($processed_time_data,$correct,$data_count,$student_count,
         $ORdata,$Foils,$Concepts) = @_;
     if ($data_count <= 0) {
-        return ('<h2>'.&mt('There is no data to plot').'</h2>','');
+        return ('<div class="LC_warning">'
+               .&mt('There is no data to plot.')
+               .'</div>'
+               ,''
+        );
     }
     my $analysis_html;
     my @plotdata;
@@ -1723,23 +1749,23 @@ sub build_foil_index {
     }
     #
     # Build up the table of row labels.
-    my $table = '<table border="1" >'."\n";
+    my $table = &Apache::loncommon::start_data_table();
     if (@Concepts > 1) {
-        $table .= '<tr>'.
+        $table .= &Apache::loncommon::start_data_table_header_row().
             '<th>'.&mt('Concept Number').'</th>'.
             '<th>'.&mt('Concept').'</th>'.
             '<th>'.&mt('Foil Number').'</th>'.
             '<th>'.&mt('Foil Name').'</th>'.
             '<th>'.&mt('Foil Text').'</th>'.
             '<th>'.&mt('Correct Value').'</th>'.
-            "</tr>\n";
+            &Apache::loncommon::end_data_table_header_row();
     } else {
-        $table .= '<tr>'.
+        $table .= &Apache::loncommon::start_data_table_header_row().
             '<th>'.&mt('Foil Number').'</th>'.
             '<th>'.&mt('Foil Name').'</th>'.
             '<th>'.&mt('Foil Text').'</th>'.
             '<th>'.&mt('Correct Value').'</th>'.
-            "</tr>\n";
+            &Apache::loncommon::end_data_table_header_row();
     }        
     my $conceptindex = 1;
     my $foilindex = 1;
@@ -1747,39 +1773,39 @@ sub build_foil_index {
         my @FoilsInConcept = @{$concept->{'foils'}};
         my $firstfoil = shift(@FoilsInConcept);
         if (@Concepts > 1) {
-            $table .= '<tr>'.
+            $table .= &Apache::loncommon::start_data_table_row().
                 '<td>'.$conceptindex.'</td>'.
                 '<td>'.&HTML::Entities::encode($concept->{'name'},'<>&"').'</td>'.
                 '<td>'.$foilindex++.'</td>'.
                 '<td>'.&HTML::Entities::encode($Foildata{$firstfoil}->{'name'},'<>&"').'</td>'.
                 '<td>'.$Foildata{$firstfoil}->{'text'}.'</td>'.
                 '<td>'.&HTML::Entities::encode($Foildata{$firstfoil}->{'value'},'<>&"').'</td>'.
-                "</tr>\n";
+                &Apache::loncommon::end_data_table_row();
         } else {
-            $table .= '<tr>'.
+            $table .= &Apache::loncommon::start_data_table_row().
                 '<td>'.$foilindex++.'</td>'.
                 '<td>'.&HTML::Entities::encode($Foildata{$firstfoil}->{'name'},'<>&"').'</td>'.
                 '<td>'.$Foildata{$firstfoil}->{'text'}.'</td>'.
                 '<td>'.&HTML::Entities::encode($Foildata{$firstfoil}->{'value'},'<>&"').'</td>'.
-                "</tr>\n";
+                &Apache::loncommon::end_data_table_row();
         }
         foreach my $foilid (@FoilsInConcept) {
             if (@Concepts > 1) {
-                $table .= '<tr>'.
+                $table .= &Apache::loncommon::start_data_table_row().
                     '<td></td>'.
                     '<td></td>'.
                     '<td>'.$foilindex.'</td>'.
                     '<td>'.&HTML::Entities::encode($Foildata{$foilid}->{'name'},'<>&"').'</td>'.
                     '<td>'.$Foildata{$foilid}->{'text'}.'</td>'.
                     '<td>'.&HTML::Entities::encode($Foildata{$foilid}->{'value'},'<>&"').'</td>'.
-                    "</tr>\n";
+                    &Apache::loncommon::end_data_table_row();
             } else {
-                $table .= '<tr>'.
+                $table .= &Apache::loncommon::start_data_table_row().
                     '<td>'.$foilindex.'</td>'.
                     '<td>'.&HTML::Entities::encode($Foildata{$foilid}->{'name'},'<>&"').'</td>'.
                     '<td>'.$Foildata{$foilid}->{'text'}.'</td>'.
                     '<td>'.&HTML::Entities::encode($Foildata{$foilid}->{'value'},'<>&"').'</td>'.
-                    "</tr>\n";
+                    &Apache::loncommon::end_data_table_row();
             }                
         } continue {
             $foilindex++;
@@ -1787,7 +1813,7 @@ sub build_foil_index {
     } continue {
         $conceptindex++;
     }
-    $table .= "</table>\n";
+    $table .= &Apache::loncommon::end_data_table();
     #
     # Build option index with color stuff
     return ($table,\@Foils,\@Concepts);
@@ -1850,16 +1876,18 @@ sub CreateInterface {
     ## Build the menu
     my $Str = '';
     $Str .= &Apache::lonhtmlcommon::breadcrumbs('Detailed Problem Analysis');
-    $Str .= '<table cellspacing="5">'."\n";
-    $Str .= '<tr>';
-    $Str .= '<td align="center"><b>'.&mt('Sections').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Groups').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Access Status').'</b></td>';
-    $Str .= '<td align="center">&nbsp;</td>';
-    $Str .= '</tr>'."\n";
+    $Str .= '<p>';
+    $Str .= &Apache::loncommon::start_data_table();
+    $Str .= &Apache::loncommon::start_data_table_header_row();
+    $Str .= '<th>'.&mt('Sections').'</th>';
+    $Str .= '<th>'.&mt('Groups').'</th>';
+    $Str .= '<th>'.&mt('Access Status').'</th>';
+    $Str .= '<th>'.&mt('Options').'</th>';
+    $Str .= &Apache::loncommon::end_data_table_header_row();
     ##
     ## 
-    $Str .= '<tr><td align="center">'."\n";
+    $Str .= &Apache::loncommon::start_data_table_row();
+    $Str .= '<td align="center">'."\n";
     $Str .= &Apache::lonstatistics::SectionSelect('Section','multiple',5);
     $Str .= '</td>';
     #
@@ -1873,35 +1901,35 @@ sub CreateInterface {
     #
     ##
     ##
-    $Str .= '<td>';
+    $Str .= '<td align="right" valign="top">';
     ##
     my $showprob_checkbox = 
         '<input type="checkbox" name="show_prob" value="true" ';
     if ($env{'form.show_prob'} eq 'true') {
-        $showprob_checkbox .= 'checked ';
+        $showprob_checkbox .= 'checked="checked" ';
     }
     $showprob_checkbox.= ' />';
-    $Str.= '<nobr><label>'.
+    $Str.= '<span class="LC_nobreak"><label>'.
         &mt('Show problem [_1]',$showprob_checkbox).
-        '</label></nobr><br />';
+        '</label></span><br />';
     ##
     my $analyze_selector = '<select name="AnalyzeOver" >';
     $analyze_selector .= '<option value="tries" ';
     if (! exists($env{'form.AnalyzeOver'}) || 
         $env{'form.AnalyzeOver'} eq 'tries'){
         # Default to tries
-        $analyze_selector .= ' selected ';
+        $analyze_selector .= ' selected="selected" ';
     }
     $analyze_selector .= '>'.&mt('Tries').'</option>';
     $analyze_selector .= '<option value="time" ';
     $analyze_selector .= ' selected ' if ($env{'form.AnalyzeOver'} eq 'time');
     $analyze_selector .= '>'.&mt('Time').'</option>';
     $analyze_selector .= '</select>';
-    $Str .= '<nobr><label>'.
+    $Str .= '<span class="LC_nobreak"><label>'.
         &mt('Analyze Over [_1] [_2]',
             $analyze_selector,
             &Apache::loncommon::help_open_topic('Analysis_Analyze_Over')).
-            '</label></nobr><br />'.$/;
+            '</label></span><br />'.$/;
     ##
     my $numplots_selector = '<select name="NumPlots">';
     if (! exists($env{'form.NumPlots'}) 
@@ -1911,23 +1939,24 @@ sub CreateInterface {
     }
     foreach my $i (1,2,3,4,5,6,7,8,10,15,20) {
         $numplots_selector .= '<option value="'.$i.'" ';
-        if ($env{'form.NumPlots'} == $i) { $numplots_selector.=' selected '; }
+        if ($env{'form.NumPlots'} == $i) { $numplots_selector.=' selected="selected" '; }
         $numplots_selector .= '>'.$i.'</option>';
     }
-    $numplots_selector .= '</select></nobr><br />';
-    $Str .= '<nobr><label>'.&mt('Number of Plots [_1]',$numplots_selector).
-        '</label></nobr>';
+    $numplots_selector .= '</select>';
+    $Str .= '<span class="LC_nobreak"><label>'.&mt('Number of Plots [_1]',$numplots_selector).
+        '</label></span><br />';
     ##
-    $Str .= '<nobr><label>'.&mt('Status: [_1]',
-                                 '<input type="text" '.
-                                 'name="stats_status" size="60" value="" />'
-                                 ).
-                    '</label></nobr>';
     $Str .= '</td>';
     ##
     ##
-    $Str .= '</tr>'."\n";
-    $Str .= '</table>'."\n";
+    $Str .= &Apache::loncommon::end_data_table_row();
+    $Str .= &Apache::loncommon::end_data_table();
+    $Str .= '<p class="LC_nobreak"><label>'
+           .&mt('Status: [_1]',
+                    '<input type="text" name="stats_status"'
+                   .' size="60" value="" readonly="readonly" />')
+           .'</label></p>';
+    $Str .= '</p>';
     return $Str;
 }
 
