@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonproblemstatistics.pm,v 1.113 2008/09/11 14:47:22 bisitz Exp $
+# $Id: lonproblemstatistics.pm,v 1.115 2008/10/30 17:45:25 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -612,40 +612,49 @@ sub CreateInterface {
     my $Str = '';
     $Str .= &Apache::lonhtmlcommon::breadcrumbs('Overall Problem Statistics',
 						'Statistics_Overall_Key');
-    $Str .= '<table cellspacing="5">'."\n";
-    $Str .= '<tr>';
-    $Str .= '<td align="center"><b>'.&mt('Sections').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Groups').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Access Status').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Sequences and Folders').'</b></td>';
-    $Str .= '<td align="center"><b>'.&mt('Statistics').'</b></td>';
-    $Str .= '<td rowspan="2">'.
-        &Apache::lonstathelpers::limit_by_time_form().'</td>';
-    $Str .= '</tr>'."\n";
+    $Str .= '<p>';
+    $Str .= &Apache::loncommon::start_data_table();
+    $Str .= &Apache::loncommon::start_data_table_header_row();
+    $Str .= '<th>'.&mt('Sections').'</th>';
+    $Str .= '<th>'.&mt('Groups').'</th>';
+    $Str .= '<th>'.&mt('Access Status').'</th>';
+    $Str .= '<th>'.&mt('Sequences and Folders').'</th>';
+    $Str .= '<th>'.&mt('Statistics').'</th>';
+    $Str .= '<th>'.&mt('Plot Graph').'</th>';
+    $Str .= '<th>'.&mt('Time Period').'</th>';
+    $Str .= &Apache::loncommon::end_data_table_header_row();
     #
-    $Str .= '<tr><td align="center">'."\n";
+    $Str .= &Apache::loncommon::start_data_table_row();
+    $Str .= '<td align="center" valign="top">'."\n";
     $Str .= &Apache::lonstatistics::SectionSelect('Section','multiple',5);
-    $Str .= '</td><td align="center">';
+    $Str .= '</td><td align="center" valign="top">';
     $Str .= &Apache::lonstatistics::GroupSelect('Group','multiple',5);
-    $Str .= '</td><td align="center">';
+    $Str .= '</td><td align="center" valign="top">';
     $Str .= &Apache::lonhtmlcommon::StatusOptions(undef,undef,5);
-    $Str .= '</td><td align="center">';
+    $Str .= '</td><td align="center" valign="top">';
     #
     $Str .= &Apache::lonstatistics::map_select('Maps','multiple,all',5);
-    $Str .= '</td><td>'.&field_selection_input();
-    $Str .= '</td></tr>'."\n";
-    $Str .= '</table>'."\n";
+    $Str .= '</td><td align="center" valign="top">';
+    $Str .= &field_selection_input();
+    $Str .= '</td><td align="center" valign="top">';
+    $Str .= &plot_dropdown();
+    $Str .= '</td>'."\n";
+    $Str .= '</td><td align="center" valign="top">';
+    $Str .= &Apache::lonstathelpers::limit_by_time_form();
+    $Str .= '</td>'."\n";
+    $Str .=  &Apache::loncommon::end_data_table_row();
+    $Str .= &Apache::loncommon::end_data_table();
     #
-    $Str .= '<p>'.&mt('Status: [_1]',
-                         '<input type="text" '.
-                         'name="stats_status" size="60" value="" />'
-                         ).
-                         '</nobr></p>';
+    $Str .= '<p><span class="LC_nobreak">'
+           .&mt('Status: [_1]',
+                    '<input type="text" name="stats_status"'
+                   .' size="60" value="" readonly="readonly" />')
+           .'</span></p>';
     #
+    $Str .= '</p>';
     $Str .= '<input type="submit" name="GenerateStatistics" value="'.
         &mt('Generate Statistics').'" />';
-    $Str .= '&nbsp;'x5;
-    $Str .= 'Plot '.&plot_dropdown().('&nbsp;'x10);
+    $Str .= ('&nbsp;'x10);
     #
     return $Str;
 }
@@ -728,7 +737,7 @@ sub BuildProblemStatisticsPage {
     ($navmap,@sequences) = 
         &Apache::lonstatistics::selected_sequences_with_assessments();
     if (! ref($navmap)) {
-        $r->print('<h1>'.&mt('A course-wide error occurred.').'</h1>'.
+        $r->print('<div class="LC_error">'.&mt('A course-wide error occurred.').'</div>'.
                   '<h3>'.$navmap.'</h3>');
 	&clean_up();
         return;
