@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstathelpers.pm,v 1.55 2008/09/14 15:16:29 raeburn Exp $
+# $Id: lonstathelpers.pm,v 1.56 2008/10/30 17:45:25 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -158,7 +158,7 @@ sub problem_selector {
                                                      resptype=>$resptype});
                         my $checked = '';
                         if ($env{'form.problemchoice'} eq $value) {
-                            $checked = 'checked ';
+                            $checked = 'checked="checked" ';
                         }
                         my $title = $res->compTitle;
                         if (! defined($title) || $title eq '') {
@@ -173,7 +173,7 @@ sub problem_selector {
                         }
                         my $link = $res->link.'?symb='.&escape($res->shown_symb);
                         $seq_str .= ('&nbsp;'x2).
-                            qq{<a target="preview" href="$link">view</a>};
+                            '<a target="preview" href="'.$link.'">'.&mt('view').'</a>';
                         $seq_str .= "</td></tr>\n";
                         $rb_count++;
                     }
@@ -229,8 +229,9 @@ sub MultipleProblemSelector {
     if (! defined($navmap)) {
         $navmap = Apache::lonnavmaps::navmap->new();
         if (! defined($navmap)) {
-            $Str .= 
-                '<h1>'.&mt('Error: cannot process course structure').'</h1>';
+            $Str .= '<div class="LC_error">'
+                   .&mt('Error: cannot process course structure')
+                   .'</div>';
             return $Str;
         }
     }
@@ -321,7 +322,7 @@ sub new_accumulator {
                 $target.='<tr><td><label>'.
                     '<input type="checkbox" name="'.$inputname.'" ';
                 if ($checked) {
-                    $target .= 'checked ';
+                    $target .= 'checked="checked" ';
                 }
                 $target .= 'id="'.$seq_id.':'.$item_id++.'" ';
                 $target.= 
@@ -329,7 +330,7 @@ sub new_accumulator {
                     '&nbsp;'.$res->compTitle.'</label>'.
                     ('&nbsp;'x2).'<a target="preview" '.
                     'href="'.$res->link.'?symb='.
-                    &escape($res->shown_symb).'">view</a>'.
+                    &escape($res->shown_symb).'">'.&mt('view').'</a>'.
                     '</td></tr>'.$/;
             } else { 
                 if (defined($target)) {
