@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.90 2008/09/24 17:30:18 raeburn Exp $
+# $Id: loncfile.pm,v 1.91 2008/12/19 14:01:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -159,7 +159,7 @@ sub URLToPath {
     my $Url = shift;
     &Debug($r, "UrlToPath got: $Url");
     $Url=~ s/\/+/\//g;
-    $Url=~ s/^http\:\/\/[^\/]+//;
+    $Url=~ s/^https?\:\/\/[^\/]+//;
     $Url=~ s/^\///;
     $Url=~ s/(\~|priv\/)($match_username)\//\/home\/$2\/public_html\//;
     &Debug($r, "Returning $Url \n");
