@@ -1,5 +1,5 @@
 # Handler for parsing text upload problem descriptions into .problems
-# $Id: testbankimport.pm,v 1.18 2008/09/24 19:48:29 raeburn Exp $
+# $Id: testbankimport.pm,v 1.19 2008/12/19 03:53:00 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1817,7 +1817,7 @@ sub handler {
     my ($fn,$filename);
     if ($env{'form.filename'}) {
         $fn=$env{'form.filename'};
-        $fn=~s/^http\:\/\/[^\/]+\///;
+        $fn=~s/^https?\:\/\/[^\/]+\///;
         $fn=~s/^\///;
         $fn=~s{(~|priv/)($LONCAPA::username_re)}{};
         $fn=~s/\/+/\//g;
