@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Dynamic plot
 #
-# $Id: lonplot.pm,v 1.148 2008/09/02 19:55:23 raeburn Exp $
+# $Id: lonplot.pm,v 1.148.2.1 2008/12/11 22:48:56 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1433,7 +1433,7 @@ sub start_data {
 	}
 	# complain if the number of data points is not the same as
 	# in previous sets of data.
-	if (($curves[-1]->{'data'}) && ($#data != $#{@{$curves[-1]->{'data'}->[0]}})){
+	if (($curves[-1]->{'data'}) && ($#data != $#{$curves[-1]->{'data'}->[0]})){
 	    &Apache::lonxml::warning
 		('Number of data points is not consistent with previous '.
 		 'number of data points');
