@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.148 2008/09/10 19:45:23 droeschl Exp $
+# $Id: scripttag.pm,v 1.148.2.1 2008/12/11 21:30:10 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -44,8 +44,7 @@ BEGIN {
 			     'window','display','storetc','physnet',
 			     'standalone','comment','num','parse','algebra',
 			     'LONCAPA_INTERNAL_TURN_STYLE_ON',
-			     'LONCAPA_INTERNAL_TURN_STYLE_OFF',
-			     'LONCAPA_INTERNAL_LONHTTPD_PORT'));
+			     'LONCAPA_INTERNAL_TURN_STYLE_OFF'));
 }
 
 sub start_LONCAPA_INTERNAL_TURN_STYLE_ON {
@@ -81,29 +80,6 @@ sub end_LONCAPA_INTERNAL_TURN_STYLE_OFF {
     return ('','no');
 }
 
-=pod 
-
-=item start_LONCAPA_INTERNAL_LONHTTPD_PORT
-
-emits a pice of javascript that says a global js variable to the
-current lonhttp port, currently used by the remote control to find out
-where to load images from
-
-=cut
-
-sub start_LONCAPA_INTERNAL_LONHTTPD_PORT {
-    my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
-    if ($target eq 'web' || $target eq 'webgrade') {
-	return '<script type="text/javascript">var lonhttpdport=\''.
-	    &Apache::loncommon::lonhttpd_port().'\';</script>';
-    }
-    return ('','no');
-}
-
-sub end_LONCAPA_INTERNAL_LONHTTPD_PORT {
-    return ('','no');
-}
-
 sub start_script {
   my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
   @Apache::scripttag::parser_env = @_;
