@@ -2,7 +2,7 @@
 #
 # Page flip handler
 #
-# $Id: lonpageflip.pm,v 1.75 2008/03/12 02:45:50 raeburn Exp $
+# $Id: lonpageflip.pm,v 1.75.2.1 2008/12/21 05:00:52 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -335,7 +335,7 @@ sub handler {
 	     return REDIRECT;
 	 }
       }
-      $currenturl=~s/^http\:\/\///;
+      $currenturl=~s/^https?\:\/\///;
       $currenturl=~s/^[^\/]+//;
 #
 # Is the current URL on the map? If not, start with last known URL
