@@ -2,7 +2,7 @@
 #
 # Sequence Handler
 #
-# $Id: lonsequence.pm,v 1.32 2007/12/01 01:59:54 albertel Exp $
+# $Id: lonsequence.pm,v 1.32.2.1 2008/12/21 04:53:39 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -278,7 +278,8 @@ sub handler {
       &Apache::lonnet::symblist($requrl,$disurl => [$disurl,$dismapid],
 				'last_known' => [$disurl,$dismapid]); 
       &Apache::loncommon::content_type($r,'text/html');
-      $r->header_out(Location => 'http://'.$ENV{'HTTP_HOST'}.$disurl);
+      $r->header_out(Location => &Apache::lonnet::absolute_url($ENV{'SERVER_NAME'}).
+                                 $disurl);
       return REDIRECT;
    } else {
        &Apache::loncommon::content_type($r,'text/html');
